Class: Google::Apis::RecommenderV1::GoogleCloudRecommenderV1Impact

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/recommender_v1/classes.rb,
lib/google/apis/recommender_v1/representations.rb,
lib/google/apis/recommender_v1/representations.rb

Overview

Contains the impact a recommendation can have for a given category.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudRecommenderV1Impact

Returns a new instance of GoogleCloudRecommenderV1Impact.



91
92
93
# File 'lib/google/apis/recommender_v1/classes.rb', line 91

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#categoryString

Category that is being targeted. Corresponds to the JSON property category

Returns:

  • (String)


63
64
65
# File 'lib/google/apis/recommender_v1/classes.rb', line 63

def category
  @category
end

#cost_projectionGoogle::Apis::RecommenderV1::GoogleCloudRecommenderV1CostProjection

Contains metadata about how much money a recommendation can save or incur. Corresponds to the JSON property costProjection



68
69
70
# File 'lib/google/apis/recommender_v1/classes.rb', line 68

def cost_projection
  @cost_projection
end

#reliability_projectionGoogle::Apis::RecommenderV1::GoogleCloudRecommenderV1ReliabilityProjection

Contains information on the impact of a reliability recommendation. Corresponds to the JSON property reliabilityProjection



73
74
75
# File 'lib/google/apis/recommender_v1/classes.rb', line 73

def reliability_projection
  @reliability_projection
end

#security_projectionGoogle::Apis::RecommenderV1::GoogleCloudRecommenderV1SecurityProjection

Contains various ways of describing the impact on Security. Corresponds to the JSON property securityProjection



78
79
80
# File 'lib/google/apis/recommender_v1/classes.rb', line 78

def security_projection
  @security_projection
end

#serviceString

The service that this impact is associated with. Corresponds to the JSON property service

Returns:

  • (String)


83
84
85
# File 'lib/google/apis/recommender_v1/classes.rb', line 83

def service
  @service
end

#sustainability_projectionGoogle::Apis::RecommenderV1::GoogleCloudRecommenderV1SustainabilityProjection

Contains metadata about how much sustainability a recommendation can save or incur. Corresponds to the JSON property sustainabilityProjection



89
90
91
# File 'lib/google/apis/recommender_v1/classes.rb', line 89

def sustainability_projection
  @sustainability_projection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



96
97
98
99
100
101
102
103
# File 'lib/google/apis/recommender_v1/classes.rb', line 96

def update!(**args)
  @category = args[:category] if args.key?(:category)
  @cost_projection = args[:cost_projection] if args.key?(:cost_projection)
  @reliability_projection = args[:reliability_projection] if args.key?(:reliability_projection)
  @security_projection = args[:security_projection] if args.key?(:security_projection)
  @service = args[:service] if args.key?(:service)
  @sustainability_projection = args[:sustainability_projection] if args.key?(:sustainability_projection)
end