Class: Google::Apis::RecommenderV1::GoogleCloudRecommenderV1ListInsightsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RecommenderV1::GoogleCloudRecommenderV1ListInsightsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recommender_v1/classes.rb,
lib/google/apis/recommender_v1/representations.rb,
lib/google/apis/recommender_v1/representations.rb
Overview
Response to the ListInsights method.
Instance Attribute Summary collapse
-
#insights ⇒ Array<Google::Apis::RecommenderV1::GoogleCloudRecommenderV1Insight>
The set of insights for the
parentresource. -
#next_page_token ⇒ String
A token that can be used to request the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecommenderV1ListInsightsResponse
constructor
A new instance of GoogleCloudRecommenderV1ListInsightsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecommenderV1ListInsightsResponse
Returns a new instance of GoogleCloudRecommenderV1ListInsightsResponse.
343 344 345 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 343 def initialize(**args) update!(**args) end |
Instance Attribute Details
#insights ⇒ Array<Google::Apis::RecommenderV1::GoogleCloudRecommenderV1Insight>
The set of insights for the parent resource.
Corresponds to the JSON property insights
335 336 337 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 335 def insights @insights end |
#next_page_token ⇒ String
A token that can be used to request the next page of results. This field is
empty if there are no additional results.
Corresponds to the JSON property nextPageToken
341 342 343 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 341 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
348 349 350 351 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 348 def update!(**args) @insights = args[:insights] if args.key?(:insights) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |