Class: Google::Apis::RecommenderV1::GoogleCloudRecommenderV1ListRecommendationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::RecommenderV1::GoogleCloudRecommenderV1ListRecommendationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recommender_v1/classes.rb,
lib/google/apis/recommender_v1/representations.rb,
lib/google/apis/recommender_v1/representations.rb
Overview
Response to the ListRecommendations method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token that can be used to request the next page of results.
-
#recommendations ⇒ Array<Google::Apis::RecommenderV1::GoogleCloudRecommenderV1Recommendation>
The set of recommendations for the
parentresource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecommenderV1ListRecommendationsResponse
constructor
A new instance of GoogleCloudRecommenderV1ListRecommendationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecommenderV1ListRecommendationsResponse
Returns a new instance of GoogleCloudRecommenderV1ListRecommendationsResponse.
369 370 371 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 369 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token that can be used to request the next page of results. This field is
empty if there are no additional results.
Corresponds to the JSON property nextPageToken
362 363 364 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 362 def next_page_token @next_page_token end |
#recommendations ⇒ Array<Google::Apis::RecommenderV1::GoogleCloudRecommenderV1Recommendation>
The set of recommendations for the parent resource.
Corresponds to the JSON property recommendations
367 368 369 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 367 def recommendations @recommendations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
374 375 376 377 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 374 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @recommendations = args[:recommendations] if args.key?(:recommendations) end |