Class: Google::Apis::RecommenderV1::GoogleCloudRecommenderV1OperationGroup
- Inherits:
-
Object
- Object
- Google::Apis::RecommenderV1::GoogleCloudRecommenderV1OperationGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/recommender_v1/classes.rb,
lib/google/apis/recommender_v1/representations.rb,
lib/google/apis/recommender_v1/representations.rb
Overview
Group of operations that need to be performed atomically.
Instance Attribute Summary collapse
-
#operations ⇒ Array<Google::Apis::RecommenderV1::GoogleCloudRecommenderV1Operation>
List of operations across one or more resources that belong to this group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudRecommenderV1OperationGroup
constructor
A new instance of GoogleCloudRecommenderV1OperationGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudRecommenderV1OperationGroup
Returns a new instance of GoogleCloudRecommenderV1OperationGroup.
617 618 619 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#operations ⇒ Array<Google::Apis::RecommenderV1::GoogleCloudRecommenderV1Operation>
List of operations across one or more resources that belong to this group.
Loosely based on RFC6902 and should be performed in the order they appear.
Corresponds to the JSON property operations
615 616 617 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 615 def operations @operations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
622 623 624 |
# File 'lib/google/apis/recommender_v1/classes.rb', line 622 def update!(**args) @operations = args[:operations] if args.key?(:operations) end |